summaryrefslogtreecommitdiffstats
path: root/editor/dependency_editor.cpp
diff options
context:
space:
mode:
authorkobewi <kobewi4e@gmail.com>2023-02-11 23:47:43 +0100
committerkobewi <kobewi4e@gmail.com>2023-06-13 11:09:56 +0200
commit06eff95d64a9b387a442d31fc8d133ae942ad8aa (patch)
tree65b6c645621f60e92266a95c253c12fb6a143950 /editor/dependency_editor.cpp
parentae896bbd85d0c9f1883c81f138045c3753ccef01 (diff)
downloadredot-engine-06eff95d64a9b387a442d31fc8d133ae942ad8aa.tar.gz
Fix missing UID handling in Dependency Editor
Diffstat (limited to 'editor/dependency_editor.cpp')
-rw-r--r--editor/dependency_editor.cpp14
1 files changed, 10 insertions, 4 deletions
diff --git a/editor/dependency_editor.cpp b/editor/dependency_editor.cpp
index eaafad7ab8..3660e7f285 100644
--- a/editor/dependency_editor.cpp
+++ b/editor/dependency_editor.cpp
@@ -191,10 +191,16 @@ void DependencyEditor::_update_list() {
ResourceUID::ID uid = ResourceUID::get_singleton()->text_to_id(path);
if (uid != ResourceUID::INVALID_ID) {
- // dependency is in uid format, obtain proper path
- ERR_CONTINUE(!ResourceUID::get_singleton()->has_id(uid));
-
- path = ResourceUID::get_singleton()->get_id_path(uid);
+ // Dependency is in uid format, obtain proper path.
+ if (ResourceUID::get_singleton()->has_id(uid)) {
+ path = ResourceUID::get_singleton()->get_id_path(uid);
+ } else if (n.get_slice_count("::") >= 3) {
+ // If uid can't be found, try to use fallback path.
+ path = n.get_slice("::", 2);
+ } else {
+ ERR_PRINT("Invalid dependency UID and fallback path.");
+ continue;
+ }
}
String name = path.get_file();